summaryrefslogtreecommitdiff
path: root/gcc/emit-rtl.c
diff options
context:
space:
mode:
authornathan <nathan@138bc75d-0d04-0410-961f-82ee72b054a4>2003-06-27 09:49:44 +0000
committernathan <nathan@138bc75d-0d04-0410-961f-82ee72b054a4>2003-06-27 09:49:44 +0000
commit31b97e8fe86bbd7d884d4322610e2500391e723c (patch)
tree76c304e23f54cc8ab0fd72acd18ea077e9e50f60 /gcc/emit-rtl.c
parent4862d777da0da56f4bc76208e67305b4c5e7df27 (diff)
downloadgcc-31b97e8fe86bbd7d884d4322610e2500391e723c.tar.gz
* rtl.h (emit_note): Remove FILE parameter.
* emit-rtl.c (emit_line_note): Adjust emit_note call. (emit_note): Remove FILE parameter. Adjust. * builtins.c (expand_builtin_expect): Adjust emit_note call. * c-semantics.c (genrtl_scope_stmt): Likewise. (expand_stmt): Likewise. * cfglayout.c (reemit_insn_block_notes): Likewise. (duplicate_insn_chain): Likewise. * except.c (expand_eh_region_start, expand_eh_region_end, sjlj_emit_function_enter): Likewise. * explow.c (probe_stack_range): Likewise. * expr.c (emit_block_move_via_loop): Likewise. * function.c (init_function_start, expand_function_start, expand_function_end, thread_prologue_and_epilogue_insns): Likewise. * integrate.c (expand_inline_function, copy_insn_list): Likewise. * reg-stack.c (compensate_edge): Likewise. * reload1.c (reload): Likewise. * rtlanal.c (hoist_insn_to_edge): Likewise. * stmt.c (expand_fixup, expand_start_loop, expand_start_null_loop, expand_loop_continue_here, expand_end_loop, expand_continue_loop, expand_exit_loop_top_cond, expand_value_return, expand_start_bindings_and_block, expand_end_bindings, expand_decl_cleanup, expand_start_case): Likewise. * unroll.c (copy_loop_body * config/alpha/alpha.c (alpha_output_mi_thunk_osf): Likewise. * config/ia64/ia64.c (ia64_output_mi_thunk): Likewise. * config/rs6000/rs6000.c (rs6000_emit_eh_toc_restore, rs6000_emit_allocate_stack, rs6000_output_function_prologue, rs6000_output_function_epilogue, rs6000_output_mi_thunk): Likewise. * config/sh/sh.c (sh_output_mi_thunk): Likewise. * config/sparc/sparc.c (sparc_output_mi_thunk): Likewise. * ada/misc.c (record_code_position): Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@68561 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/emit-rtl.c')
-rw-r--r--gcc/emit-rtl.c22
1 files changed, 12 insertions, 10 deletions
diff --git a/gcc/emit-rtl.c b/gcc/emit-rtl.c
index 908b12db8ca..d54d1885258 100644
--- a/gcc/emit-rtl.c
+++ b/gcc/emit-rtl.c
@@ -4899,6 +4899,8 @@ emit_line_note (file, line)
const char *file;
int line;
{
+ rtx note;
+
if (line < 0)
abort ();
@@ -4916,25 +4918,25 @@ emit_line_note (file, line)
return NULL_RTX;
}
- return emit_note (file, line);
+ note = emit_note (line);
+ NOTE_SOURCE_FILE (note) = file;
+
+ return note;
}
-/* Make an insn of code NOTE
- with data-fields specified by FILE and LINE
- and add it to the end of the doubly-linked list.
- If it is a line-number NOTE, omit it if it matches the previous one. */
+/* Make an insn of code NOTE or type NOTE_NO
+ and add it to the end of the doubly-linked list. */
rtx
-emit_note (file, line)
- const char *file;
- int line;
+emit_note (note_no)
+ int note_no;
{
rtx note;
note = rtx_alloc (NOTE);
INSN_UID (note) = cur_insn_uid++;
- NOTE_SOURCE_FILE (note) = file;
- NOTE_LINE_NUMBER (note) = line;
+ NOTE_LINE_NUMBER (note) = note_no;
+ NOTE_DATA (note) = 0;
BLOCK_FOR_INSN (note) = NULL;
add_insn (note);
return note;